# int2az
## Utility for translating numbers into Azerbaijani.
### 1. How to use
```python
from int2az import Int2Az
Int2Az.convert(123)
```
**Output:**
```python
 'bir yüz iyirmi üç'
```
### 2. Restrictions
Input number must be in Integer format and below **1000000000** *(Its possible to raise this number, contact me if you have such problem or fork this repo and make necessery changes ;) )*

### 3. PS
Azerbaijani is not my home language. Moreover, I do not know Azerbaijani at all. So, if you will find any mistakes in translations - please contact me and i will try to fix this.
